<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
class Branding extends Model
{
    use HasFactory;
    protected $appends = ['path'];
    protected $fillable = [
        'name','area','price','width','height','total','image'
    ];
    public static function BrandingSaveData($request){
        $request->validate([
            'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048', // Adjust validation rules as needed
        ]);
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $imageName = time() . '.' . $image->getClientOriginalExtension();

            // Check if the directory exists, create it if not
            if (!Storage::exists('public/branding')) {
                Storage::makeDirectory('public/branding');
            }

            // Store the image in the branding directory
            $imagePath = $image->storeAs('public/branding', $imageName);
            $imageUrl = str_replace('public/', '', $imagePath);
            Branding::create([
                'image' => $imageUrl,
                'name' => $request->input('name'),
                'width' => $request->input('width'),
                'height' => $request->input('height'),
                'area' => $request->input('total_area'),
                'price' => $request->input('fixed_price'),
                'total' => $request->input('total_price'),
            ]);
            return back()->with('success', 'Record Added successfully.');
        }

        return back()->with('error', 'Failed to upload image.');
    }

    public static function getAllBranding(){
        $data = Branding::all();
        if ($data->isNotEmpty()) {
            // The branding table has data
            return $data;
        }else{
            return $arr = [
                [
                    'name' => 'Logo T-Shirt',
                    'price' => 19.99,
                    'image' => 'https://placehold.co/150x150',
                    'width' => 1200,
                    'height' => 1200,                    
                    'status' => false,
                ],
                [
                    'name' => 'Branded Notebook',
                    'price' => 9.99,
                    'image' => 'https://placehold.co/150x150',
                    'width' => 800,
                    'height' => 800,
                    'status' => false,
                ],
                [
                    'name' => 'Promotional Pen Set',
                    'price' => 5.99,
                    'image' => 'https://placehold.co/150x150',
                    'width' => 1000,
                    'height' => 1000,
                    'status' => false,
                ],
                [
                    'name' => 'Custom Water Bottle',
                    'price' => 14.99,
                    'image' => 'https://placehold.co/150x150',
                    'width' => 1500,
                    'height' => 1500,
                    'status' => false,
                ],
            ];
        }
    }
    public static function updateById($request){
        $findRecord = Branding::find($request->input('id')); 
        if ($request->hasFile('image')) {
            $deleteImage = 'public/' . $findRecord->image;
            Storage::delete($deleteImage);
            // Store the new image
            $image = $request->file('image');
            $imageName = time() . '.' . $image->getClientOriginalExtension();
            $imagePath = $image->storeAs('public/branding', $imageName);
            $imageUrl = str_replace('public/', '', $imagePath);
        
            // Update the image path in the database
            $findRecord->image = $imageUrl;
        }
            $findRecord->name = $request->input('name');
            $findRecord->width = $request->input('width');
            $findRecord->height = $request->input('height');
            $findRecord->area = $request->input('total_area');
            $findRecord->price = $request->input('fixed_price');
            $findRecord->total = $request->input('fixed_price');
            $findRecord->save();
        return back()->with('success', 'Record Updated successfully.');
    }
    public function media()
    {
        return $this->belongsTo('App\Models\Media', 'media_id');
    }
    public function getpathAttribute($id)
    {
        return $id . 'sad';
    }
    public static function updateRequirement($request, $id)
    {
        if (BrandingRequirement::where(['user_id' => $id])->exists()) {
            // If records exist, delete them
            BrandingRequirement::where(['user_id' => $id])->delete();
            // You can also add any additional logic or messages here
        }
        $brandingRequirement = new BrandingRequirement;
        if (isset($request->branding_requirement['id'])) {
            $brandingRequirement->id = $request->branding_requirement['id'];
        }
        $brandingRequirement->fill($request->branding_requirement);
        $brandingRequirement->user_id = $id;
        $brandingRequirement->save();
        BrandingRequirementDetails::where(['branding_requirement_id' => $brandingRequirement->id])->delete();
        foreach ($request->branding_requirement_details as $detail) {
            $brandingRequirementDetail = new BrandingRequirementDetails;
            if (isset($detail['id'])) {
                $brandingRequirementDetail->id = $detail['id'];
                unset($detail['id']);
            }
            $brandingRequirementDetail->name = $detail['name'];
            $brandingRequirementDetail->branding_required = $detail['branding_required'];
            $brandingRequirementDetail->price = $detail['price'];
            $brandingRequirementDetail->total = $detail['total'];
            $brandingRequirementDetail->branding_requirement_id = $brandingRequirement->id;
            $brandingRequirementDetail->save();
        };
    }
}
