<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Exhibitor extends User
{
    protected $table = 'users';
    
    public static function billCategory()
    {
        return [
            'stall','sponsership','branding','power','furniture','catalogue_advertising'
        ];
    }
    
    public function profile()
    {
        return $this->hasOne('App\Models\ExhibitorProfile', 'user_id');
    }
    public function stall()
    {
        return $this->hasOne('App\Models\ExhibitorStall', 'exhibitor_profile_id');
    }

    public function powerRequirement()
    {
        return $this->hasOne('App\Models\PowerRequirement', 'user_id');
    }

    public function furnitureRequirement()
    {
        return $this->hasOne('App\Models\FurnitureRequirement', 'user_id');
    }

    public function advertisementRequirement()
    {
        return $this->hasOne('App\Models\AdvertisementRequirement', 'user_id');
    }

    public function payment()
    {
        return $this->hasMany('App\Models\Payment', 'user_id');
    }
    
    public function products()
    {
        return $this->belongsToMany('App\Models\Product', 'product_users', 'user_id', 'product_id');
    }
    public function brandingRequirement()
    {
        return $this->hasOne('App\Models\BrandingRequirement', 'user_id');
    }
    public function getTotalTdsAttribute()
    {
        return array_reduce($this->payment->all(), function($total, $payment){
            return $total + $payment->tds;
        }, 0);
    }
  

    public function getTotalPaymentAttribute()
    {
        return array_reduce($this->payment->all(), function($total, $payment){
            return $payment->amount;
        }, 0);
    }

    public function getPaymentRecievedAttribute()
    {
        return array_reduce($this->payment->all(), function($total, $payment){
            return $total + $payment->tds + $payment->amount;
        }, 0);
    }

    public static function list()
    {
        return ['name','email','address','city','state','pin','mobile','telephone','fax','website','product','brandsondisplay','brandsondisplay_distributors','brandsondisplay_international'];
    }
  
    public function getTotalAmountAttribute()
    {
        return array_reduce($this->payment->all(), function($total, $payment){
            return $total + $payment->amount;
        }, 0);
    }
    public static function getExhibitorInfo($id){
        $details = ExhibitorProfile::where('user_id',$id)->first();
        return $details->company_name;
    }
    public function getTerms()
    {
        return $this->hasOne('App\Models\ExhibitorTerm', 'exhibitor_id');
    }
    public function getPendingAmountAttribute()
    {
        return array_reduce($this->payment->all(), function($total, $payment){
            return $total + $payment->tds + $payment->amount;
        }, 0);
    }
}
